/* @flow */

import {
  InputTypeComposer,
  type ComposeInputFieldConfigAsObject
} from "graphql-compose";
import { getTypeName, getOrSetType, desc } from "../../../utils";
import { getAnalyzedAsFieldConfigMap } from "../../Commons/FieldNames";

export function getCommonITC(
  opts: mixed = {}
): InputTypeComposer | ComposeInputFieldConfigAsObject {
  const name = getTypeName("QueryCommon", opts);
  const description = desc(
    `
    The common terms query is a modern alternative to stopwords which improves
    the precision and recall of search results (by taking stopwords into account),
    without sacrificing performance.
    [Documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-common-terms-query.html)
  `
  );

  const subName = getTypeName("QueryCommonSettings", opts);
  const fields = getAnalyzedAsFieldConfigMap(
    opts,
    getOrSetType(subName, () =>
      InputTypeComposer.create({
        name: subName,
        fields: {
          query: "String",
          cutoff_frequency: "Float",
          minimum_should_match: "JSON",
          low_freq_operator: "String",
          high_freq_operator: "String",
          boost: "Float"
        }
      })
    )
  );

  if (typeof fields === "object") {
    return getOrSetType(name, () =>
      InputTypeComposer.create({
        name,
        description,
        fields
      })
    );
  }

  return {
    type: "JSON",
    description
  };
}
